# -*- coding: utf-8 -*-
    </div>
    <%include file="sidebar.tpl"/>
    <div class="clear"></div>
    </div>

    <div id="footer">	
      This website is proudly powered by <a href="https://github.com/evilsocket/SWG" target="_blank">SWG</a> v${config.version}
      <br/>
      Lonelytree theme by <a href="http://www.gauson.com" target="_blank">Gauson Design</a>
    </div>

  </div>
</body>
</html>


